package com.cultural.heritage.controller.global;

import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.cultural.heritage.annotation.AuthCheck;
import com.cultural.heritage.common.BaseResponse;
import com.cultural.heritage.common.ResultUtils;
import com.cultural.heritage.constant.OrderStatusConstant;
import com.cultural.heritage.constant.UserConstant;
import com.cultural.heritage.model.entity.*;
import com.cultural.heritage.model.vo.clothes.ClothesLabelVO;
import com.cultural.heritage.model.vo.photoProducts.PhotoProductsLabelVO;
import com.cultural.heritage.service.book.AdvanceOrderService;
import com.cultural.heritage.service.book.PhotoCategoryService;
import com.cultural.heritage.service.book.PhotoProductsService;
import com.cultural.heritage.service.clothes.ClothesCategoryService;
import com.cultural.heritage.service.clothes.ClothesService;
import com.cultural.heritage.service.common.CommonService;
import com.cultural.heritage.service.good.GoodService;
import com.cultural.heritage.service.order.OrderService;
import com.google.gson.Gson;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.math.BigDecimal;
import java.util.*;

@RestController
@RequestMapping("/global")
@Slf4j
@Tag(name = "获取全局数据接口")
public class GlobalController {


    @Resource
    private OrderService orderService;


    @Resource
    private AdvanceOrderService advanceOrderService;


    @Resource
    private GoodService goodService;


    @Resource
    private PhotoProductsService photoProductsService;


    @Resource
    private PhotoCategoryService photoCategoryService;


    @Resource
    private ClothesCategoryService clothesCategoryService;


    @Resource
    private ClothesService clothesService;


    @Resource
    private CommonService commonService;




    /**
     * Web端管理员查看全局数据
     * @return Map集合
     */
    @PostMapping("/queryAll")
    @Operation(summary = "Web端管理员查看全局数据", description = "参数：无，权限：管理员(admin, boss)，方法名：delAppointmentDateById")
    @AuthCheck(mustRole = UserConstant.ADMIN_ROLE)
    public BaseResponse<Object> getDashboardData() {

        List<String> orderStatusList = List.of(OrderStatusConstant.PENDING_SHIPMENT, OrderStatusConstant.PENDING_DELIVERY, OrderStatusConstant.TRANSACTION_SUCCESSFUL);
        Map<String, Object> map = new HashMap<>();
        // 获取今天的开始时间和结束时间
        Date startOfDay = DateUtil.beginOfDay(new Date());  // 今天的开始时间（00:00:00）
        Date endOfDay = DateUtil.endOfDay(new Date());     // 今天的结束时间（23:59:59）

        QueryWrapper<Order> orderQueryWrapper = new QueryWrapper<>();
        orderQueryWrapper.between("updateTime", startOfDay, endOfDay);
        orderQueryWrapper.in("orderStatus", orderStatusList);

        List<Order> orderList = orderService.list(orderQueryWrapper);

        List<Order> productOrderList = orderList.stream().filter(order -> order.getOrderType().equals("product")).toList();
        BigDecimal productTotalAmount = new BigDecimal("0.00");
        for (Order order : productOrderList) {
            BigDecimal orderAmount = order.getTotalAmount();
            productTotalAmount = productTotalAmount.add(orderAmount);
        }
        map.put("今日实体类商品订单数", productOrderList.size());
        map.put("今日实体类商品订单营业额", productTotalAmount);


        List<Order> serviceOrderList = orderList.stream().filter(order -> order.getOrderType().equals("service")).toList();
        BigDecimal serviceTotalAmount = new BigDecimal("0.00");
        for (Order order : serviceOrderList) {
            BigDecimal orderAmount = order.getTotalAmount();
            serviceTotalAmount = serviceTotalAmount.add(orderAmount);
        }
        map.put("今日服务类商品订单数", serviceOrderList.size());
        map.put("今日服务类商品订单营业额", serviceTotalAmount);


        QueryWrapper<AdvanceOrder> advanceOrderQueryWrapper = new QueryWrapper<>();
        advanceOrderQueryWrapper.between("updateTime", startOfDay, endOfDay);
        advanceOrderQueryWrapper.in("orderStatus", OrderStatusConstant.PENDING_SHIPMENT, OrderStatusConstant.TRANSACTION_SUCCESSFUL);

        List<AdvanceOrder> advanceOrderList = advanceOrderService.list(advanceOrderQueryWrapper);
        BigDecimal advanceTotalAmount = new BigDecimal("0.00");
        for (AdvanceOrder advanceOrder : advanceOrderList) {
            BigDecimal orderAmount = advanceOrder.getTotalAmount();
            advanceTotalAmount = advanceTotalAmount.add(orderAmount);
        }
        map.put("今日写真预约订单数", advanceOrderList.size());
        map.put("今日写真预约类订单营业额", advanceTotalAmount);


        // 获取所有待支付订单
        List<Order> pendingPaymentOrderList = orderList.stream().filter(order -> order.getOrderStatus().equals(OrderStatusConstant.PENDING_PAYMENT)).toList();
        // 获取待发货实体类订单
        List<Order> productPendingShipmentOrderList = orderList.stream().filter(order ->
                order.getOrderStatus().equals(OrderStatusConstant.PENDING_SHIPMENT)
             && order.getOrderType().equals("product")).toList();
        // 获取待消费服务类订单
        List<Order> servicePendingShipmentOrderList = orderList.stream().filter(order ->
                order.getOrderStatus().equals(OrderStatusConstant.PENDING_SHIPMENT)
                        && order.getOrderType().equals("service")).toList();

        map.put("所有待支付订单数量", pendingPaymentOrderList.size());
        map.put("实体类待发货订单", productPendingShipmentOrderList.size());
        map.put("服务类待消费订单", servicePendingShipmentOrderList.size());

        // 获取待拍摄写真预约订单
        List<AdvanceOrder> pendingShipmentAdvanceOrderList = advanceOrderList.stream().filter(advanceOrder -> advanceOrder.getOrderStatus().equals(OrderStatusConstant.PENDING_SHIPMENT)).toList();
        map.put("写真预约类待拍摄订单", pendingShipmentAdvanceOrderList.size());

        List<Good> goodList = goodService.list();
        List<Good> isShelvesGoodList = goodList.stream().filter(good -> good.getIsShelves() == 1).toList();
        List<Good> isNoShelvesGoodList = goodList.stream().filter(good -> good.getIsShelves() == 0).toList();

        map.put("全部商品数量", goodList.size());
        map.put("全部已上架商品数量", isShelvesGoodList.size());
        map.put("全部已下架商品数量", isNoShelvesGoodList.size());

        Gson gson = new Gson();
        String json = gson.toJson(map);
        Object obj = gson.fromJson(json, Object.class);
        return ResultUtils.success(obj);
    }





    /**
     * 小程序端获取所有的写真产品和服装产品
     * @return  map
     */
    @GetMapping("/getAllProducts")
    @Operation(summary = "小程序端获取所有的写真产品和服装产品", description = "参数：无，权限：所有人，方法名：getAllPhotoProductsAndClothes")
    public BaseResponse<Map<String, Object>> getAllPhotoProductsAndClothes() {
        Map<String, List<PhotoProductsLabelVO>> photoProductsMap = new HashMap<>();
        List<PhotoProducts> photoProductsList = commonService.findByFieldEqTargetField("isShelves", 1, photoProductsService);
        List<PhotoProductsLabelVO> photoProductsLabelVOS = commonService.convertList(photoProductsList, PhotoProductsLabelVO.class);

        for (PhotoProductsLabelVO photoProductsLabelVO : photoProductsLabelVOS) {
            String categoryName = photoProductsLabelVO.getCategoryName();
            List<PhotoProductsLabelVO> photoProductsLabelVOList = photoProductsMap.get(categoryName);
            if (photoProductsLabelVOList == null) {
                photoProductsLabelVOList = new ArrayList<>();
            }
            photoProductsLabelVOList.add(photoProductsLabelVO);
            photoProductsMap.put(categoryName, photoProductsLabelVOList);
        }

        // 获取所有的服装类别
        Map<Long, String> idToName = new HashMap<>();
        List<ClothesCategory> clothesCategoryList = clothesCategoryService.list();
        for (ClothesCategory clothesCategory : clothesCategoryList) {
            idToName.put(clothesCategory.getId(), clothesCategory.getName());
        }

        Map<String, List<ClothesLabelVO>> clothesMap = new HashMap<>();
        List<Clothes> clothesList = commonService.findByFieldEqTargetField("isShelves", 1, clothesService);
        List<ClothesLabelVO> clothesLabelVOS = commonService.convertList(clothesList, ClothesLabelVO.class);

        for (ClothesLabelVO clothesLabelVO : clothesLabelVOS) {
            Long id = clothesLabelVO.getCategoryId();
            String type = idToName.get(id);
            List<ClothesLabelVO> clothesLabelVOList = clothesMap.get(type);
            if (clothesLabelVOList == null) {
                clothesLabelVOList = new ArrayList<>();
            }
            clothesLabelVOList.add(clothesLabelVO);
            clothesMap.put(type, clothesLabelVOList);
        }

        Map<String, Object> map = new HashMap<>();
        map.put("clothesMap", clothesMap);
        map.put("photoProductsMap", photoProductsMap);

        return ResultUtils.success(map);
    }





}
