package com.cultural.heritage.service.address.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.exception.BusinessException;
import com.cultural.heritage.exception.ThrowUtils;
import com.cultural.heritage.mapper.ContactsMapper;
import com.cultural.heritage.model.entity.Contacts;
import com.cultural.heritage.service.address.ContactsService;
import com.cultural.heritage.utils.RegexUtils;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.List;

@Service
public class ContactsServiceImpl extends ServiceImpl<ContactsMapper, Contacts> implements ContactsService {


    @Override
    public void verifyIsDefault(Contacts contacts) {
        Integer isDefault = contacts.getIsDefault();
        Long userId = contacts.getUserId();
        List<Contacts> list = this.getUserContactsById(userId);
        if (CollectionUtils.isEmpty(list)) {
            return ;
        }
        if (isDefault == 1) {
            list.forEach(item -> item.setIsDefault(0));
        }
        boolean result = this.updateBatchById(list);
        ThrowUtils.throwIf(!result, ErrorCode.OPERATION_ERROR);
    }

    @Override
    public List<Contacts> getUserContactsById(Long userId) {
        QueryWrapper<Contacts> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("userId", userId);
        List<Contacts> list = this.list(queryWrapper);
        return list;
    }


    /**
     * 校验用户提交的地址信息
     */
    @Override
    public void validContacts(Contacts contacts, boolean update) {
        String name = contacts.getName();
        String phone = contacts.getPhone();
        Long userId = contacts.getUserId();
        Integer isDefault = contacts.getIsDefault();

        if (update) {
            if (userId == null) {
                throw new BusinessException(ErrorCode.PARAMS_ERROR, "参数id错误");
            }
        }
        if (ObjectUtils.isEmpty(isDefault) || isDefault != 0 && isDefault != 1) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        if (StringUtils.isAnyBlank(name, phone)) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        if (StringUtils.isNotBlank(phone) && RegexUtils.isPhoneInvalid(phone)) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "手机号格式错误");
        }
    }
}
