package com.cultural.heritage.service.wx;


import com.wechat.pay.java.service.payments.jsapi.model.PrepayWithRequestPaymentResponse;
import com.wechat.pay.java.service.payments.model.Transaction;
import com.wechat.pay.java.service.refund.model.Refund;
import com.wechat.pay.java.service.refund.model.RefundNotification;
import jakarta.servlet.http.HttpServletRequest;

import java.io.IOException;
import java.math.BigDecimal;

/**
 * @author 玄德
 */
public interface WeChatService {

    /**
     * 微信支付（商品类）
     */
    PrepayWithRequestPaymentResponse createPayment(String orderId, String miniOpenId, BigDecimal amount);

    /**
     * 微信支付（写真预约类）
     */
    PrepayWithRequestPaymentResponse createPhotoProductsPayment(String orderId, String miniOpenId, BigDecimal amount);

    /**
     * 微信支付（服装租赁类）
     */
    PrepayWithRequestPaymentResponse createClothesRentPayment(String valueOf, String miniOpenId, BigDecimal totalAmount);

    /**
     * 获取支付回调信息
     */
    Transaction getTransactionInfo(HttpServletRequest request);

    /**
     * 支付回调（商品类）
     */
    boolean paymentCallback(Transaction transaction) throws IOException;

    /**
     * 支付回调(写真预约类）
     */
    boolean paymentPhotoProductsCallback(Transaction transaction) throws IOException;

    /**
     * 支付回调（服装租赁类）
     */
    boolean paymentClothesRentCallback(Transaction transaction);

    /**
     * 全额退款申请（商品类）
     */
    Refund refundPayment(String orderId, BigDecimal amount);

    /**
     * 全额退款申请（写真预约类）
     */
    Refund refundPhotoProductsPayment(String orderId, BigDecimal amount);

    /**
     * 全额退款申请（服装租赁类）
     */
    Refund refundClothesRentPayment(String orderId, BigDecimal totalAmount);

    /**
     * 部分退款申请
     */
    Refund refundPartPayment(String orderItemsId, BigDecimal amount);

    /**
     * 剩余退款申请
     */
    Refund refundRestPayment(String orderId, BigDecimal totalAmount);

    /**
     * 获取退款回调信息
     */
    RefundNotification getRefundInfo(HttpServletRequest request);



    /**
     * 全额退款回调（商品类）
     */
    boolean refundCallback(RefundNotification refundNotification);

    /**
     * 全额退款回调（写真预约类）
     */
    boolean refundPhotoProductsCallback(RefundNotification refundNotification);

    /**
     * 全额退款回调（服装租赁类）
     */
    boolean refundClothesRentCallback(RefundNotification refundNotification);

    /**
     * 部分退款回调
     */
    boolean refundPartCallback(RefundNotification refundNotification);


    /**
     * 剩余退款回调
     */
    boolean refundRestCallback(RefundNotification refundNotification);




//    /**
//     * 发送订阅模板消息
//     */
//    boolean sendSubscribeMessage(String openid, String templateId);

}
