package com.cultural.heritage.service.wx.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.constant.CommonConstant;
import com.cultural.heritage.exception.BusinessException;
import com.cultural.heritage.exception.ThrowUtils;
import com.cultural.heritage.mapper.OfficialAccountArticleMapper;
import com.cultural.heritage.model.dto.article.OfficialAccountArticleQueryRequest;
import com.cultural.heritage.model.entity.OfficialAccountArticle;
import com.cultural.heritage.service.wx.WeChatOfficialAccountService;
import com.cultural.heritage.utils.SqlUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

@Service
public class WeChatOfficialAccountServiceImpl extends ServiceImpl<OfficialAccountArticleMapper, OfficialAccountArticle> implements WeChatOfficialAccountService {


    /**
     * 校验
     */
    @Override
    public void validArticle(OfficialAccountArticle officialAccountArticle, boolean update) {
        Long id = officialAccountArticle.getId();
        String title = officialAccountArticle.getTitle();
        String publishTime = officialAccountArticle.getPublishTime();
        String url = officialAccountArticle.getUrl();
        String image = officialAccountArticle.getImage();

        ThrowUtils.throwIf(update && id == null, ErrorCode.OPERATION_ERROR, "id参数错误");
        if (StringUtils.isAnyBlank(title, publishTime, url, image)) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "存在参数为空");
        }


    }

    @Override
    public QueryWrapper<OfficialAccountArticle> getQueryWrapper(OfficialAccountArticleQueryRequest officialAccountArticleQueryRequest) {
        QueryWrapper<OfficialAccountArticle> queryWrapper = new QueryWrapper<>();
        String sortField = officialAccountArticleQueryRequest.getSortField();
        String sortOrder = officialAccountArticleQueryRequest.getSortOrder();
        queryWrapper.orderBy(SqlUtils.validSortField(sortField), sortOrder.equals(CommonConstant.SORT_ORDER_ASC), sortField);
        return queryWrapper;
    }
}
